#include <stdio.h>
#include "yalloca.h"
int porting_dbg(const char *fmt,...);

int alloca_call(AllocaArg *ap)
{	char buff[STACK1];
	int size;

	if( 0 < ap->s_count-- )
		return alloca_call(ap);
	else{
		if( ap->s_trace ){
			size = ap->s_sp0 - (unsigned int)(&ap);
			porting_dbg("%s (%4d) = %5d [%08x - %08x]",
			ap->s_what,ap->s_size,size,(unsigned int)&ap,ap->s_sp0);
		}
		return (*ap->s_func)(ap->s_av[0],ap->s_av[1],
				ap->s_av[2],ap->s_av[3]);
	}
}
int INHERENT_alloca(){ return 0; }
